==> cdktf_cdktf_provider_azurerm-0.5.16-py3-none-any.whl: package/lib/data-azurerm-function-app.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataAzurermFunctionAppConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app#name DataAzurermFunctionApp#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app#resource_group_name DataAzurermFunctionApp#resource_group_name}.
     *
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app#tags DataAzurermFunctionApp#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app#timeouts DataAzurermFunctionApp#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DataAzurermFunctionAppTimeouts;
}
/**
 * @stability stable
 */
export declare class DataAzurermFunctionAppConnectionString extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    get value(): string;
}
/**
 * @stability stable
 */
export declare class DataAzurermFunctionAppIdentity extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get identityIds(): string[];
    /**
     * @stability stable
     */
    get principalId(): string;
    /**
     * @stability stable
     */
    get tenantId(): string;
    /**
     * @stability stable
     */
    get type(): string;
}
/**
 * @stability stable
 */
export declare class DataAzurermFunctionAppSiteConfigCors extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get allowedOrigins(): string[];
    /**
     * @stability stable
     */
    get supportCredentials(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class DataAzurermFunctionAppSiteConfigIpRestrictionHeaders extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get xAzureFdid(): string[];
    /**
     * @stability stable
     */
    get xFdHealthProbe(): string[];
    /**
     * @stability stable
     */
    get xForwardedFor(): string[];
    /**
     * @stability stable
     */
    get xForwardedHost(): string[];
}
/**
 * @stability stable
 */
export declare class DataAzurermFunctionAppSiteConfigIpRestriction extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get action(): string;
    /**
     * @stability stable
     */
    get headers(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get ipAddress(): string;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get priority(): number;
    /**
     * @stability stable
     */
    get serviceTag(): string;
    /**
     * @stability stable
     */
    get virtualNetworkSubnetId(): string;
}
/**
 * @stability stable
 */
export declare class DataAzurermFunctionAppSiteConfigScmIpRestrictionHeaders extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get xAzureFdid(): string[];
    /**
     * @stability stable
     */
    get xFdHealthProbe(): string[];
    /**
     * @stability stable
     */
    get xForwardedFor(): string[];
    /**
     * @stability stable
     */
    get xForwardedHost(): string[];
}
/**
 * @stability stable
 */
export declare class DataAzurermFunctionAppSiteConfigScmIpRestriction extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get action(): string;
    /**
     * @stability stable
     */
    get headers(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get ipAddress(): string;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get priority(): number;
    /**
     * @stability stable
     */
    get serviceTag(): string;
    /**
     * @stability stable
     */
    get virtualNetworkSubnetId(): string;
}
/**
 * @stability stable
 */
export declare class DataAzurermFunctionAppSiteConfig extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get alwaysOn(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get appScaleLimit(): number;
    /**
     * @stability stable
     */
    get autoSwapSlotName(): string;
    /**
     * @stability stable
     */
    get cors(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get dotnetFrameworkVersion(): string;
    /**
     * @stability stable
     */
    get elasticInstanceMinimum(): number;
    /**
     * @stability stable
     */
    get ftpsState(): string;
    /**
     * @stability stable
     */
    get healthCheckPath(): string;
    /**
     * @stability stable
     */
    get http2Enabled(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get ipRestriction(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get javaVersion(): string;
    /**
     * @stability stable
     */
    get linuxFxVersion(): string;
    /**
     * @stability stable
     */
    get minTlsVersion(): string;
    /**
     * @stability stable
     */
    get preWarmedInstanceCount(): number;
    /**
     * @stability stable
     */
    get runtimeScaleMonitoringEnabled(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get scmIpRestriction(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get scmType(): string;
    /**
     * @stability stable
     */
    get scmUseMainIpRestriction(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get use32BitWorkerProcess(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get vnetRouteAllEnabled(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get websocketsEnabled(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class DataAzurermFunctionAppSiteCredential extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get password(): string;
    /**
     * @stability stable
     */
    get username(): string;
}
/**
 * @stability stable
 */
export declare class DataAzurermFunctionAppSourceControl extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get branch(): string;
    /**
     * @stability stable
     */
    get manualIntegration(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get repoUrl(): string;
    /**
     * @stability stable
     */
    get rollbackEnabled(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get useMercurial(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface DataAzurermFunctionAppTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app#read DataAzurermFunctionApp#read}.
     *
     * @stability stable
     */
    readonly read?: string;
}
export declare function dataAzurermFunctionAppTimeoutsToTerraform(struct?: DataAzurermFunctionAppTimeoutsOutputReference | DataAzurermFunctionAppTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class DataAzurermFunctionAppTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DataAzurermFunctionAppTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DataAzurermFunctionAppTimeouts | undefined);
    private _read?;
    /**
     * @stability stable
     */
    get read(): string;
    /**
     * @stability stable
     */
    set read(value: string);
    /**
     * @stability stable
     */
    resetRead(): void;
    /**
     * @stability stable
     */
    get readInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/function_app azurerm_function_app}.
 *
 * @stability stable
 */
export declare class DataAzurermFunctionApp extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/function_app azurerm_function_app} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataAzurermFunctionAppConfig);
    /**
     * @stability stable
     */
    get appServicePlanId(): string;
    /**
     * @stability stable
     */
    appSettings(key: string): string | cdktf.IResolvable;
    /**
     * @stability stable
     */
    get clientCertMode(): string;
    /**
     * @stability stable
     */
    connectionString(index: string): DataAzurermFunctionAppConnectionString;
    /**
     * @stability stable
     */
    get customDomainVerificationId(): string;
    /**
     * @stability stable
     */
    get defaultHostname(): string;
    /**
     * @stability stable
     */
    get enabled(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    identity(index: string): DataAzurermFunctionAppIdentity;
    /**
     * @stability stable
     */
    get location(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get osType(): string;
    /**
     * @stability stable
     */
    get outboundIpAddresses(): string;
    /**
     * @stability stable
     */
    get possibleOutboundIpAddresses(): string;
    private _resourceGroupName?;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string | undefined;
    /**
     * @stability stable
     */
    siteConfig(index: string): DataAzurermFunctionAppSiteConfig;
    /**
     * @stability stable
     */
    siteCredential(index: string): DataAzurermFunctionAppSiteCredential;
    /**
     * @stability stable
     */
    sourceControl(index: string): DataAzurermFunctionAppSourceControl;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): DataAzurermFunctionAppTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: DataAzurermFunctionAppTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DataAzurermFunctionAppTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf_cdktf_provider_azurerm-0.5.58-py3-none-any.whl: package/lib/data-azurerm-function-app.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermFunctionAppConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app#name DataAzurermFunctionApp#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app#resource_group_name DataAzurermFunctionApp#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app#tags DataAzurermFunctionApp#tags}
    */
    readonly tags?: {
        [key: string]: string;
    };
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app#timeouts DataAzurermFunctionApp#timeouts}
    */
    readonly timeouts?: DataAzurermFunctionAppTimeouts;
}
export declare class DataAzurermFunctionAppConnectionString extends cdktf.ComplexComputedList {
    get name(): string;
    get type(): string;
    get value(): string;
}
export declare class DataAzurermFunctionAppIdentity extends cdktf.ComplexComputedList {
    get identityIds(): string[];
    get principalId(): string;
    get tenantId(): string;
    get type(): string;
}
export declare class DataAzurermFunctionAppSiteConfigCors extends cdktf.ComplexComputedList {
    get allowedOrigins(): string[];
    get supportCredentials(): cdktf.IResolvable;
}
export declare class DataAzurermFunctionAppSiteConfigIpRestrictionHeaders extends cdktf.ComplexComputedList {
    get xAzureFdid(): string[];
    get xFdHealthProbe(): string[];
    get xForwardedFor(): string[];
    get xForwardedHost(): string[];
}
export declare class DataAzurermFunctionAppSiteConfigIpRestriction extends cdktf.ComplexComputedList {
    get action(): string;
    get headers(): cdktf.IResolvable;
    get ipAddress(): string;
    get name(): string;
    get priority(): number;
    get serviceTag(): string;
    get virtualNetworkSubnetId(): string;
}
export declare class DataAzurermFunctionAppSiteConfigScmIpRestrictionHeaders extends cdktf.ComplexComputedList {
    get xAzureFdid(): string[];
    get xFdHealthProbe(): string[];
    get xForwardedFor(): string[];
    get xForwardedHost(): string[];
}
export declare class DataAzurermFunctionAppSiteConfigScmIpRestriction extends cdktf.ComplexComputedList {
    get action(): string;
    get headers(): cdktf.IResolvable;
    get ipAddress(): string;
    get name(): string;
    get priority(): number;
    get serviceTag(): string;
    get virtualNetworkSubnetId(): string;
}
export declare class DataAzurermFunctionAppSiteConfig extends cdktf.ComplexComputedList {
    get alwaysOn(): cdktf.IResolvable;
    get appScaleLimit(): number;
    get autoSwapSlotName(): string;
    get cors(): cdktf.IResolvable;
    get dotnetFrameworkVersion(): string;
    get elasticInstanceMinimum(): number;
    get ftpsState(): string;
    get healthCheckPath(): string;
    get http2Enabled(): cdktf.IResolvable;
    get ipRestriction(): cdktf.IResolvable;
    get javaVersion(): string;
    get linuxFxVersion(): string;
    get minTlsVersion(): string;
    get preWarmedInstanceCount(): number;
    get runtimeScaleMonitoringEnabled(): cdktf.IResolvable;
    get scmIpRestriction(): cdktf.IResolvable;
    get scmType(): string;
    get scmUseMainIpRestriction(): cdktf.IResolvable;
    get use32BitWorkerProcess(): cdktf.IResolvable;
    get vnetRouteAllEnabled(): cdktf.IResolvable;
    get websocketsEnabled(): cdktf.IResolvable;
}
export declare class DataAzurermFunctionAppSiteCredential extends cdktf.ComplexComputedList {
    get password(): string;
    get username(): string;
}
export declare class DataAzurermFunctionAppSourceControl extends cdktf.ComplexComputedList {
    get branch(): string;
    get manualIntegration(): cdktf.IResolvable;
    get repoUrl(): string;
    get rollbackEnabled(): cdktf.IResolvable;
    get useMercurial(): cdktf.IResolvable;
}
export interface DataAzurermFunctionAppTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app#read DataAzurermFunctionApp#read}
    */
    readonly read?: string;
}
export declare function dataAzurermFunctionAppTimeoutsToTerraform(struct?: DataAzurermFunctionAppTimeoutsOutputReference | DataAzurermFunctionAppTimeouts | cdktf.IResolvable): any;
export declare class DataAzurermFunctionAppTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): DataAzurermFunctionAppTimeouts | undefined;
    set internalValue(value: DataAzurermFunctionAppTimeouts | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/function_app azurerm_function_app}
*/
export declare class DataAzurermFunctionApp extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/function_app azurerm_function_app} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermFunctionAppConfig
    */
    constructor(scope: Construct, id: string, config: DataAzurermFunctionAppConfig);
    get appServicePlanId(): string;
    appSettings(key: string): string | cdktf.IResolvable;
    get clientCertMode(): string;
    connectionString(index: string): DataAzurermFunctionAppConnectionString;
    get customDomainVerificationId(): string;
    get defaultHostname(): string;
    get enabled(): cdktf.IResolvable;
    get id(): string;
    identity(index: string): DataAzurermFunctionAppIdentity;
    get location(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get osType(): string;
    get outboundIpAddresses(): string;
    get possibleOutboundIpAddresses(): string;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    siteConfig(index: string): DataAzurermFunctionAppSiteConfig;
    siteCredential(index: string): DataAzurermFunctionAppSiteCredential;
    sourceControl(index: string): DataAzurermFunctionAppSourceControl;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _timeouts;
    get timeouts(): DataAzurermFunctionAppTimeoutsOutputReference;
    putTimeouts(value: DataAzurermFunctionAppTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): DataAzurermFunctionAppTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
